==> zhongyan-manage-service-api-3.0.31-sources.jar: cn/com/duiba/cloud/manage/service/api/model/dto/report/RetentionDto.java <==
package cn.com.duiba.cloud.manage.service.api.model.dto.report;

import lombok.Data;

import java.io.Serializable;

/**
 * @author: LuHui
 * @Date: 2022/10/14 13:49
 * @Description: 留存率
 */
@Data
public class RetentionDto implements Serializable {
    private static final long serialVersionUID = -4888162495356079814L;

    /**
     * 日期
     */
    private String date;
    /**
     * 访问次日留存率
     */
    private String visitYesterdayRetention;
    /**
     * 访问3日留存率
     */
    private String visitThreeDayRetention;
    /**
     * 访问7日留存率
     */
    private String visitSevenDayRetention;
    /**
     * 访问15日留存率
     */
    private String visitFifteenDayRetention;
    /**
     * 参与次日留存率
     */
    private String joinYesterdayRetention;
    /**
     * 参与3日留存率
     */
    private String joinThreeDayRetention;
    /**
     * 参与7日留存率
     */
    private String joinSevenDayRetention;
    /**
     * 参与15日留存率
     */
    private String joinFifteenDayRetention;
    /**
     * 连续3日UV
     */
    private Long continueThreeDayUV;
    /**
     * 连续7日UV
     */
    private Long continueSevenDayUV;
    /**
     * 连续15日UV
     */
    private Long continueFifteenDayUV;
    /**
     * 连续21日UV
     */
    private Long continueTwentyOneDayUV;
    /**
     * 累计1天UV
     */
    private Long lastOneDayUv;
    /**
     * 累计2天UV
     */
    private Long lastTwoDayUv;
    /**
     * 累计3天UV
     */
    private Long lastThreeDayUv;
    /**
     * 累计4天UV
     */
    private Long lastFourDayUv;
    /**
     * 累计5天UV
     */
    private Long lastFiveDayUv;
    /**
     * 累计6天UV
     */
    private Long lastSixDayUv;
    /**
     * 累计7天UV
     */
    private Long lastSevenDayUv;
    /**
     * 累计8天UV
     */
    private Long lastEightDayUv;
    /**
     * 累计9天UV
     */
    private Long lastNineDayUv;
    /**
     * 累计10天UV
     */
    private Long lastTenDayUv;
    /**
     * 累计11天UV
     */
    private Long lastElevenDayUv;
    /**
     * 累计12天UV
     */
    private Long lastTwelveDayUv;
    /**
     * 累计13天UV
     */
    private Long lastThirteenDayUv;
    /**
     * 累计14天UV
     */
    private Long lastFourteenDayUv;
    /**
     * 累计15天UV
     */
    private Long lastFifteenDayUv;
    /**
     * 累计16天UV
     */
    private Long lastSixteenDayUv;
    /**
     * 累计17天UV
     */
    private Long lastSeventeenDayUv;
    /**
     * 累计18天UV
     */
    private Long lastEighteenDayUv;
    /**
     * 累计19天UV
     */
    private Long lastNineteenDayUv;
    /**
     * 累计20天UV
     */
    private Long lastTwentyDayUv;
    /**
     * 累计21天UV
     */
    private Long lastTwentyOneDayUv;

    /**
     * 被统计这一天的所有数据都已经完成统计
     */
    private Boolean dataFinishFlag;
}

==> zhongyan-manage-service-api-3.0.51-sources.jar: cn/com/duiba/cloud/manage/service/api/model/dto/report/RetentionDto.java <==
package cn.com.duiba.cloud.manage.service.api.model.dto.report;

import lombok.Data;

import java.io.Serializable;

/**
 * @author: LuHui
 * @Date: 2022/10/14 13:49
 * @Description: 留存率
 */
@Data
public class RetentionDto implements Serializable {
    private static final long serialVersionUID = -4888162495356079814L;

    /**
     * 日期
     */
    private String date;
    /**
     * 访问次日留存率
     */
    private String visitYesterdayRetention;
    /**
     * 访问3日留存率
     */
    private String visitThreeDayRetention;
    /**
     * 访问7日留存率
     */
    private String visitSevenDayRetention;
    /**
     * 访问13日留存率
     */
    private String visitThirteenDayRetention;
    /**
     * 访问15日留存率
     */
    private String visitFifteenDayRetention;
    /**
     * 参与次日留存率
     */
    private String joinYesterdayRetention;
    /**
     * 参与3日留存率
     */
    private String joinThreeDayRetention;
    /**
     * 参与7日留存率
     */
    private String joinSevenDayRetention;
    /**
     * 参与13日留存率
     */
    private String joinThirteenDayRetention;
    /**
     * 参与15日留存率
     */
    private String joinFifteenDayRetention;
    /**
     * 连续3日UV
     */
    private Long continueThreeDayUV;
    /**
     * 连续7日UV
     */
    private Long continueSevenDayUV;
    /**
     * 连续15日UV
     */
    private Long continueFifteenDayUV;
    /**
     * 连续21日UV
     */
    private Long continueTwentyOneDayUV;
    /**
     * 累计1天UV
     */
    private Long lastOneDayUv;
    /**
     * 累计2天UV
     */
    private Long lastTwoDayUv;
    /**
     * 累计3天UV
     */
    private Long lastThreeDayUv;
    /**
     * 累计4天UV
     */
    private Long lastFourDayUv;
    /**
     * 累计5天UV
     */
    private Long lastFiveDayUv;
    /**
     * 累计6天UV
     */
    private Long lastSixDayUv;
    /**
     * 累计7天UV
     */
    private Long lastSevenDayUv;
    /**
     * 累计8天UV
     */
    private Long lastEightDayUv;
    /**
     * 累计9天UV
     */
    private Long lastNineDayUv;
    /**
     * 累计10天UV
     */
    private Long lastTenDayUv;
    /**
     * 累计11天UV
     */
    private Long lastElevenDayUv;
    /**
     * 累计12天UV
     */
    private Long lastTwelveDayUv;
    /**
     * 累计13天UV
     */
    private Long lastThirteenDayUv;
    /**
     * 累计14天UV
     */
    private Long lastFourteenDayUv;
    /**
     * 累计15天UV
     */
    private Long lastFifteenDayUv;
    /**
     * 累计16天UV
     */
    private Long lastSixteenDayUv;
    /**
     * 累计17天UV
     */
    private Long lastSeventeenDayUv;
    /**
     * 累计18天UV
     */
    private Long lastEighteenDayUv;
    /**
     * 累计19天UV
     */
    private Long lastNineteenDayUv;
    /**
     * 累计20天UV
     */
    private Long lastTwentyDayUv;
    /**
     * 累计21天UV
     */
    private Long lastTwentyOneDayUv;

    /**
     * 被统计这一天的所有数据都已经完成统计
     */
    private Boolean dataFinishFlag;
}
